#####################################################################################
# Vse - Virtualight Shader Editor.
# 2003 Gigi Giorgi
# gigi.giorgi@ciaoweb.it
#####################################################################################

# -----------------------------------------------------------------------------------
# VERSIONE FINALE
# Commentare:
# 	- 'Control-x' in _loadShaderWin_
# 	- 'Control-x' in gui.tcl
#   - 'Control-x' in _sceneOptionsWin_ (render.tcl)
#   - inizializzazione temporanea qui a fondo file.
# _placeAtCenterOfScreen_ qui sotto al posto di wm geometry ...
# Cancellare il file data/settings.tcl
# -----------------------------------------------------------------------------------

#####################################################################################
# CONDIZIONE FONDAMENTALE - nconvert nel sistema:
#####################################################################################
if {[auto_execok nconvert.exe]==""} {
	wm withdraw .
	tk_messageBox -message "Nconvert not found (nconvert.exe must be in your PATH).\n\
		\nPlease install nconvert.exe first (http://www.xnview.com) and make sure that\
		nconvert.exe is in your PATH environment variable."
	exit
}

#####################################################################################
# CONDIZIONE FONDAMENTALE - VL nel sistema:
#####################################################################################
if {[auto_execok vlight.exe]==""} {
	wm withdraw .
	tk_messageBox -message "VirtuaLight not found (vlight.exe must be in your PATH).\n\
		\nPlease install VL first and make sure that\
		vlight.exe is in your PATH environment variable."
	exit
}
if [catch {set env(VLIGHT_ROOT)} vlrootErr] {
	wm withdraw .
	tk_messageBox -message "VirtuaLight not correctly installed.\nVLIGHT_ROOT\
		variable not set.\n\nPlease install VirtuaLight first and make sure that\
		VLIGHT_ROOT environment variable is set."
	exit
}

set se(vlRoot) \
	[file join [file dirname $env(VLIGHT_ROOT)]/[file tail $env(VLIGHT_ROOT)]]

#####################################################################################
# CONDIZIONE FONDAMENTALE - Temp valida:
#####################################################################################
if [catch {set env(TEMP)}] {
	if [file exists C:/TEMP] {
		set tmpDir C:/TEMP
	} else {
		wm withdraw .
		tk_messageBox -message "Cannot set temporary directory.\
		\n\nPlease set TEMP environment variable first."
		exit
	}
} else {
	set tmpDir [file join [file dirname $env(TEMP)]/[file tail $env(TEMP)]]
}

#####################################################################################
# CONDIZIONE FONDAMENTALE - Verifica se la dir di Vse e' scrivibile:
#####################################################################################
if ![file writable .] {
	wm withdraw .
	tk_messageBox -message "Vse system directory not writable. Exit."
	exit
}

# -----------------------------------------------------------------------------------
# Fine CONDIZIONI FONDAMENTALI
# -----------------------------------------------------------------------------------

#
# Prima volta sulla macchina, scrittura di data/settings.tcl:
#
set setFile data/settings.tcl
if ![file exists $setFile] {
	set suf [open $setFile w]
	puts $suf "set se(currShFileName) shaders.vs"
	puts $suf "set se(currShFilePath) $se(vlRoot)/Vse/shaders.vs"
	puts $suf "set se(currMpFileName) maps.vm"
	puts $suf "set se(currMpFilePath) $se(vlRoot)/Vse/maps/maps.vm"
	close $suf
}

#
# Sorgenti:
#
package require Img
source src/widgets.tcl
source data/settings.tcl
source src/settings.tcl
source src/common.tcl
source src/setvalues.tcl
source src/utils.tcl
source src/files.tcl
source src/setFiles.tcl
source src/cmap.tcl
source src/cmapFiles.tcl
source src/gui.tcl
source src/render.tcl
source src/lib.tcl

#
# Inizializzazione toplevel .
#
_placeAtCenterOfScreen_ .
#wm geometry . +10+10
wm protocol . WM_DELETE_WINDOW _exit_
wm resizable . 0 0
_ghostScale_
_clearTmpDirAll_
_sceneOptionsWin_; wm withdraw .so
wm deiconify .
# focus .; <---- NO! da' problemi con _topShell_

#
# Dirs e files di output iniziali:
#
set outputFile(dir) $se(vlRoot)/Vse
if ![file exists $outputFile(dir)] {
	if [catch {file mkdir "$outputFile(dir)"} mkdirErr] {
		tk_messageBox -parent . -message "Cannot create Vse output directory\n\
			($outputFile(dir)):\n$mkdirErr"
		exit
	}
	if ![file exists $outputFile(dir)/shaders.vs] {
		set f [open $outputFile(dir)/shaders.vs w]
		close $f
	}
	if ![file exists $outputFile(dir)/maps] {
		file mkdir $outputFile(dir)/maps
	}
	set f [open $outputFile(dir)/maps/maps.vm w]
	close $f
	tk_messageBox -parent . -message \
		"Vse new output directories created:\n\
		$outputFile(dir)\n\
		$outputFile(dir)/maps\n\
		New empty Shaders archive file shaders.vs created.\n\
		New empty Maps archive file maps.vm created.
		"
}

#####################################################################################
# Inizializzazione temporanea:
#####################################################################################
# 
# 1) new shaders --------------------------------------------------------------
# 
#_newShader_ plain  ; # unnamed1
#_newShader_ pattern; # unnamed2
#_newShader_ pattern; # unnamed3
#_showCurrThumb_
# 
# 2) load shaders --------------------------------------------------------------
#
#_loadShader_ C:/WINNT/Profiles/plgiorgi/App/Virtualight/Vse/shaders.vs unnamed1
#_loadShader_ C:/WINNT/Profiles/plgiorgi/App/Virtualight/Vse/shaders.vs unnamed2
#_loadShader_ C:/WINNT/Profiles/plgiorgi/App/Virtualight/Vse/shaders.vs unnamed3
# 
# 3) load workspace ------------------------------------------------------------
# 
#_loadWorkspace_ C:/WINNT/Profiles/plgiorgi/App/Virtualight/Vse/work1.vsw
# 
# 4) open Library win ----------------------------------------------------------
# 
#_libraryWin_
#set f1 C:/WINNT/Profiles/plgiorgi/App/Virtualight/Vse/shaders.vs
#set f2 C:/WINNT/Profiles/plgiorgi/App/Virtualight/Vse/shaders1.vs
#set se(libPath1) $f1
#set se(libFile1) [file tail $f1]
#set se(libPath2) $f2
#set se(libFile2) [file tail $f2]
#_listLibShaders_ 1
#_listLibShaders_ 2
#_loadTmpShaderContent_ $f1 1
#_loadTmpShaderContent_ $f2 2
# 
# 5) open Maps Library win ----------------------------------------------------------
# 
#_socWin_
